@@ -25,6 +25,7 @@ class Notification(Device):
         group_address: GroupAddressesType | None = None,
         group_address_state: GroupAddressesType | None = None,
         sync_state: bool | int | float | str = True,
+        value_type: str | None = None,
         device_updated_cb: DeviceCallbackType | None = None,
     ):
         """Initialize notification class."""
@@ -35,6 +36,7 @@ class Notification(Device):
             group_address=group_address,
             group_address_state=group_address_state,
             sync_state=sync_state,
+            value_type=value_type,
             device_name=name,
             feature_name="Message",
             after_update_cb=self.after_update,
