@@ -194,7 +194,7 @@ class CEMIFrame:
             + self.payload.to_knx()
         )
 
-    def __str__(self) -> str:
+    def __repr__(self) -> str:
         """Return object as readable string."""
         return (
             "<CEMIFrame "
