@@ -60,7 +60,7 @@ class SessionAuthenticate(KNXIPBody):
             + self.message_authentication_code
         )
 
-    def __str__(self) -> str:
+    def __repr__(self) -> str:
         """Return object as readable string."""
         return (
             f"<SessionAuthenticate "
